@@ -1,12 +1,14 @@
 /*
  * pw_phonemes.c --- generate secure passwords using phoneme rules
  *
- * Copyright (C) 2001 by Theodore Ts'o
+ * Copyright (C) 2001,2002 by Theodore Ts'o
  * 
  * This file may be distributed under the terms of the GNU Public
  * License.
  */
 
+#include <ctype.h>
+#include <string.h>
 #include "pwgen.h"
 
 struct pw_element elements[] = {
@@ -56,9 +58,9 @@ struct pw_element elements[] = {
 
 void pw_phonemes(char *buf, int size, int pw_flags)
 {
-	int	c, i, len, flags, feature_flags;
-	int	prev, should_be, first;
-	char	*str;
+	int		c, i, len, flags, feature_flags;
+	int		prev, should_be, first;
+	const char	*str;
 
 try_again:
 	feature_flags = pw_flags;
@@ -67,7 +69,7 @@ try_again:
 	should_be = 0;
 	first = 1;
 
-	should_be = pw_random_number(1) ? VOWEL : CONSONANT;
+	should_be = pw_random_number(2) ? VOWEL : CONSONANT;
 	
 	while (c < size) {
 		i = pw_random_number(NUM_ELEMENTS);
@@ -113,13 +115,13 @@ try_again:
 		 */
 		if (feature_flags & PW_ONE_NUMBER) {
 			if (!first && (pw_random_number(10) < 3)) {
-				buf[c++] = pw_random_number(9)+'0';
+				buf[c++] = pw_random_number(10)+'0';
 				buf[c] = 0;
 				feature_flags &= ~PW_ONE_NUMBER;
 				
 				first = 1;
 				prev = 0;
-				should_be = pw_random_number(1) ?
+				should_be = pw_random_number(2) ?
 					VOWEL : CONSONANT;
 				continue;
 			}
